# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class JobDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'briefing': 'str',
        'due_date': 'datetime',
        'state': 'str',
        'ticket_url': 'str',
        'project': 'ProjectShort',
        'branch': 'BranchName',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'owner': 'UserPreview',
        'job_tag_name': 'str',
        'source_locale': 'LocalePreview',
        'locales': 'list[LocalePreview]',
        'keys': 'list[KeyPreview]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'briefing': 'briefing',
        'due_date': 'due_date',
        'state': 'state',
        'ticket_url': 'ticket_url',
        'project': 'project',
        'branch': 'branch',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'owner': 'owner',
        'job_tag_name': 'job_tag_name',
        'source_locale': 'source_locale',
        'locales': 'locales',
        'keys': 'keys'
    }

    def __init__(self, id=None, name=None, briefing=None, due_date=None, state=None, ticket_url=None, project=None, branch=None, created_at=None, updated_at=None, owner=None, job_tag_name=None, source_locale=None, locales=None, keys=None, local_vars_configuration=None):  # noqa: E501
        """JobDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._briefing = None
        self._due_date = None
        self._state = None
        self._ticket_url = None
        self._project = None
        self._branch = None
        self._created_at = None
        self._updated_at = None
        self._owner = None
        self._job_tag_name = None
        self._source_locale = None
        self._locales = None
        self._keys = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if briefing is not None:
            self.briefing = briefing
        if due_date is not None:
            self.due_date = due_date
        if state is not None:
            self.state = state
        if ticket_url is not None:
            self.ticket_url = ticket_url
        if project is not None:
            self.project = project
        if branch is not None:
            self.branch = branch
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if owner is not None:
            self.owner = owner
        if job_tag_name is not None:
            self.job_tag_name = job_tag_name
        if source_locale is not None:
            self.source_locale = source_locale
        if locales is not None:
            self.locales = locales
        if keys is not None:
            self.keys = keys

    @property
    def id(self):
        """Gets the id of this JobDetails.  # noqa: E501


        :return: The id of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobDetails.


        :param id: The id of this JobDetails.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this JobDetails.  # noqa: E501


        :return: The name of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobDetails.


        :param name: The name of this JobDetails.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def briefing(self):
        """Gets the briefing of this JobDetails.  # noqa: E501


        :return: The briefing of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._briefing

    @briefing.setter
    def briefing(self, briefing):
        """Sets the briefing of this JobDetails.


        :param briefing: The briefing of this JobDetails.  # noqa: E501
        :type: str
        """

        self._briefing = briefing

    @property
    def due_date(self):
        """Gets the due_date of this JobDetails.  # noqa: E501


        :return: The due_date of this JobDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this JobDetails.


        :param due_date: The due_date of this JobDetails.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def state(self):
        """Gets the state of this JobDetails.  # noqa: E501


        :return: The state of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this JobDetails.


        :param state: The state of this JobDetails.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def ticket_url(self):
        """Gets the ticket_url of this JobDetails.  # noqa: E501


        :return: The ticket_url of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._ticket_url

    @ticket_url.setter
    def ticket_url(self, ticket_url):
        """Sets the ticket_url of this JobDetails.


        :param ticket_url: The ticket_url of this JobDetails.  # noqa: E501
        :type: str
        """

        self._ticket_url = ticket_url

    @property
    def project(self):
        """Gets the project of this JobDetails.  # noqa: E501


        :return: The project of this JobDetails.  # noqa: E501
        :rtype: ProjectShort
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this JobDetails.


        :param project: The project of this JobDetails.  # noqa: E501
        :type: ProjectShort
        """

        self._project = project

    @property
    def branch(self):
        """Gets the branch of this JobDetails.  # noqa: E501


        :return: The branch of this JobDetails.  # noqa: E501
        :rtype: BranchName
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this JobDetails.


        :param branch: The branch of this JobDetails.  # noqa: E501
        :type: BranchName
        """

        self._branch = branch

    @property
    def created_at(self):
        """Gets the created_at of this JobDetails.  # noqa: E501


        :return: The created_at of this JobDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this JobDetails.


        :param created_at: The created_at of this JobDetails.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this JobDetails.  # noqa: E501


        :return: The updated_at of this JobDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this JobDetails.


        :param updated_at: The updated_at of this JobDetails.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def owner(self):
        """Gets the owner of this JobDetails.  # noqa: E501


        :return: The owner of this JobDetails.  # noqa: E501
        :rtype: UserPreview
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this JobDetails.


        :param owner: The owner of this JobDetails.  # noqa: E501
        :type: UserPreview
        """

        self._owner = owner

    @property
    def job_tag_name(self):
        """Gets the job_tag_name of this JobDetails.  # noqa: E501


        :return: The job_tag_name of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_tag_name

    @job_tag_name.setter
    def job_tag_name(self, job_tag_name):
        """Sets the job_tag_name of this JobDetails.


        :param job_tag_name: The job_tag_name of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_tag_name = job_tag_name

    @property
    def source_locale(self):
        """Gets the source_locale of this JobDetails.  # noqa: E501


        :return: The source_locale of this JobDetails.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._source_locale

    @source_locale.setter
    def source_locale(self, source_locale):
        """Sets the source_locale of this JobDetails.


        :param source_locale: The source_locale of this JobDetails.  # noqa: E501
        :type: LocalePreview
        """

        self._source_locale = source_locale

    @property
    def locales(self):
        """Gets the locales of this JobDetails.  # noqa: E501


        :return: The locales of this JobDetails.  # noqa: E501
        :rtype: list[LocalePreview]
        """
        return self._locales

    @locales.setter
    def locales(self, locales):
        """Sets the locales of this JobDetails.


        :param locales: The locales of this JobDetails.  # noqa: E501
        :type: list[LocalePreview]
        """

        self._locales = locales

    @property
    def keys(self):
        """Gets the keys of this JobDetails.  # noqa: E501


        :return: The keys of this JobDetails.  # noqa: E501
        :rtype: list[KeyPreview]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this JobDetails.


        :param keys: The keys of this JobDetails.  # noqa: E501
        :type: list[KeyPreview]
        """

        self._keys = keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class UploadSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'locales_created': 'int',
        'translation_keys_created': 'int',
        'translation_keys_updated': 'int',
        'translation_keys_unmentioned': 'int',
        'translations_created': 'int',
        'translations_updated': 'int',
        'tags_created': 'int',
        'translation_keys_ignored': 'int'
    }

    attribute_map = {
        'locales_created': 'locales_created',
        'translation_keys_created': 'translation_keys_created',
        'translation_keys_updated': 'translation_keys_updated',
        'translation_keys_unmentioned': 'translation_keys_unmentioned',
        'translations_created': 'translations_created',
        'translations_updated': 'translations_updated',
        'tags_created': 'tags_created',
        'translation_keys_ignored': 'translation_keys_ignored'
    }

    def __init__(self, locales_created=None, translation_keys_created=None, translation_keys_updated=None, translation_keys_unmentioned=None, translations_created=None, translations_updated=None, tags_created=None, translation_keys_ignored=None, local_vars_configuration=None):  # noqa: E501
        """UploadSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._locales_created = None
        self._translation_keys_created = None
        self._translation_keys_updated = None
        self._translation_keys_unmentioned = None
        self._translations_created = None
        self._translations_updated = None
        self._tags_created = None
        self._translation_keys_ignored = None
        self.discriminator = None

        if locales_created is not None:
            self.locales_created = locales_created
        if translation_keys_created is not None:
            self.translation_keys_created = translation_keys_created
        if translation_keys_updated is not None:
            self.translation_keys_updated = translation_keys_updated
        if translation_keys_unmentioned is not None:
            self.translation_keys_unmentioned = translation_keys_unmentioned
        if translations_created is not None:
            self.translations_created = translations_created
        if translations_updated is not None:
            self.translations_updated = translations_updated
        if tags_created is not None:
            self.tags_created = tags_created
        if translation_keys_ignored is not None:
            self.translation_keys_ignored = translation_keys_ignored

    @property
    def locales_created(self):
        """Gets the locales_created of this UploadSummary.  # noqa: E501


        :return: The locales_created of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._locales_created

    @locales_created.setter
    def locales_created(self, locales_created):
        """Sets the locales_created of this UploadSummary.


        :param locales_created: The locales_created of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._locales_created = locales_created

    @property
    def translation_keys_created(self):
        """Gets the translation_keys_created of this UploadSummary.  # noqa: E501


        :return: The translation_keys_created of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._translation_keys_created

    @translation_keys_created.setter
    def translation_keys_created(self, translation_keys_created):
        """Sets the translation_keys_created of this UploadSummary.


        :param translation_keys_created: The translation_keys_created of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._translation_keys_created = translation_keys_created

    @property
    def translation_keys_updated(self):
        """Gets the translation_keys_updated of this UploadSummary.  # noqa: E501


        :return: The translation_keys_updated of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._translation_keys_updated

    @translation_keys_updated.setter
    def translation_keys_updated(self, translation_keys_updated):
        """Sets the translation_keys_updated of this UploadSummary.


        :param translation_keys_updated: The translation_keys_updated of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._translation_keys_updated = translation_keys_updated

    @property
    def translation_keys_unmentioned(self):
        """Gets the translation_keys_unmentioned of this UploadSummary.  # noqa: E501


        :return: The translation_keys_unmentioned of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._translation_keys_unmentioned

    @translation_keys_unmentioned.setter
    def translation_keys_unmentioned(self, translation_keys_unmentioned):
        """Sets the translation_keys_unmentioned of this UploadSummary.


        :param translation_keys_unmentioned: The translation_keys_unmentioned of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._translation_keys_unmentioned = translation_keys_unmentioned

    @property
    def translations_created(self):
        """Gets the translations_created of this UploadSummary.  # noqa: E501


        :return: The translations_created of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._translations_created

    @translations_created.setter
    def translations_created(self, translations_created):
        """Sets the translations_created of this UploadSummary.


        :param translations_created: The translations_created of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._translations_created = translations_created

    @property
    def translations_updated(self):
        """Gets the translations_updated of this UploadSummary.  # noqa: E501


        :return: The translations_updated of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._translations_updated

    @translations_updated.setter
    def translations_updated(self, translations_updated):
        """Sets the translations_updated of this UploadSummary.


        :param translations_updated: The translations_updated of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._translations_updated = translations_updated

    @property
    def tags_created(self):
        """Gets the tags_created of this UploadSummary.  # noqa: E501


        :return: The tags_created of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._tags_created

    @tags_created.setter
    def tags_created(self, tags_created):
        """Sets the tags_created of this UploadSummary.


        :param tags_created: The tags_created of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._tags_created = tags_created

    @property
    def translation_keys_ignored(self):
        """Gets the translation_keys_ignored of this UploadSummary.  # noqa: E501


        :return: The translation_keys_ignored of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._translation_keys_ignored

    @translation_keys_ignored.setter
    def translation_keys_ignored(self, translation_keys_ignored):
        """Sets the translation_keys_ignored of this UploadSummary.


        :param translation_keys_ignored: The translation_keys_ignored of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._translation_keys_ignored = translation_keys_ignored

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UploadSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TranslationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def translation_create(self, project_id, translation_create_parameters, **kwargs):  # noqa: E501
        """Create a translation  # noqa: E501

        Create a translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_create(project_id, translation_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationCreateParameters translation_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_create_with_http_info(project_id, translation_create_parameters, **kwargs)  # noqa: E501

    def translation_create_with_http_info(self, project_id, translation_create_parameters, **kwargs):  # noqa: E501
        """Create a translation  # noqa: E501

        Create a translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_create_with_http_info(project_id, translation_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationCreateParameters translation_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translation_create_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_create`")  # noqa: E501
        # verify the required parameter 'translation_create_parameters' is set
        if self.api_client.client_side_validation and ('translation_create_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_create_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_create_parameters` when calling `translation_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_create_parameters' in local_var_params:
            body_params = local_var_params['translation_create_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_exclude(self, project_id, id, translation_exclude_parameters, **kwargs):  # noqa: E501
        """Exclude a translation from export  # noqa: E501

        Set exclude from export flag on an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_exclude(project_id, id, translation_exclude_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationExcludeParameters translation_exclude_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_exclude_with_http_info(project_id, id, translation_exclude_parameters, **kwargs)  # noqa: E501

    def translation_exclude_with_http_info(self, project_id, id, translation_exclude_parameters, **kwargs):  # noqa: E501
        """Exclude a translation from export  # noqa: E501

        Set exclude from export flag on an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_exclude_with_http_info(project_id, id, translation_exclude_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationExcludeParameters translation_exclude_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'translation_exclude_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_exclude" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_exclude`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_exclude`")  # noqa: E501
        # verify the required parameter 'translation_exclude_parameters' is set
        if self.api_client.client_side_validation and ('translation_exclude_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_exclude_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_exclude_parameters` when calling `translation_exclude`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_exclude_parameters' in local_var_params:
            body_params = local_var_params['translation_exclude_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}/exclude', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_include(self, project_id, id, translation_include_parameters, **kwargs):  # noqa: E501
        """Revoke exclusion of a translation in export  # noqa: E501

        Remove exclude from export flag from an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_include(project_id, id, translation_include_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationIncludeParameters translation_include_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_include_with_http_info(project_id, id, translation_include_parameters, **kwargs)  # noqa: E501

    def translation_include_with_http_info(self, project_id, id, translation_include_parameters, **kwargs):  # noqa: E501
        """Revoke exclusion of a translation in export  # noqa: E501

        Remove exclude from export flag from an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_include_with_http_info(project_id, id, translation_include_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationIncludeParameters translation_include_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'translation_include_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_include" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_include`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_include`")  # noqa: E501
        # verify the required parameter 'translation_include_parameters' is set
        if self.api_client.client_side_validation and ('translation_include_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_include_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_include_parameters` when calling `translation_include`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_include_parameters' in local_var_params:
            body_params = local_var_params['translation_include_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}/include', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_review(self, project_id, id, translation_review_parameters, **kwargs):  # noqa: E501
        """Review a translation  # noqa: E501

        Mark an existing translation as reviewed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_review(project_id, id, translation_review_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationReviewParameters translation_review_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_review_with_http_info(project_id, id, translation_review_parameters, **kwargs)  # noqa: E501

    def translation_review_with_http_info(self, project_id, id, translation_review_parameters, **kwargs):  # noqa: E501
        """Review a translation  # noqa: E501

        Mark an existing translation as reviewed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_review_with_http_info(project_id, id, translation_review_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationReviewParameters translation_review_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'translation_review_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_review" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_review`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_review`")  # noqa: E501
        # verify the required parameter 'translation_review_parameters' is set
        if self.api_client.client_side_validation and ('translation_review_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_review_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_review_parameters` when calling `translation_review`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_review_parameters' in local_var_params:
            body_params = local_var_params['translation_review_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}/review', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_show(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single translation  # noqa: E501

        Get details on a single translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_show(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_show_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def translation_show_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single translation  # noqa: E501

        Get details on a single translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_show_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_unverify(self, project_id, id, translation_unverify_parameters, **kwargs):  # noqa: E501
        """Mark a translation as unverified  # noqa: E501

        Mark an existing translation as unverified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_unverify(project_id, id, translation_unverify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationUnverifyParameters translation_unverify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_unverify_with_http_info(project_id, id, translation_unverify_parameters, **kwargs)  # noqa: E501

    def translation_unverify_with_http_info(self, project_id, id, translation_unverify_parameters, **kwargs):  # noqa: E501
        """Mark a translation as unverified  # noqa: E501

        Mark an existing translation as unverified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_unverify_with_http_info(project_id, id, translation_unverify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationUnverifyParameters translation_unverify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'translation_unverify_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_unverify" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_unverify`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_unverify`")  # noqa: E501
        # verify the required parameter 'translation_unverify_parameters' is set
        if self.api_client.client_side_validation and ('translation_unverify_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_unverify_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_unverify_parameters` when calling `translation_unverify`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_unverify_parameters' in local_var_params:
            body_params = local_var_params['translation_unverify_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}/unverify', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_update(self, project_id, id, translation_update_parameters, **kwargs):  # noqa: E501
        """Update a translation  # noqa: E501

        Update an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_update(project_id, id, translation_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationUpdateParameters translation_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_update_with_http_info(project_id, id, translation_update_parameters, **kwargs)  # noqa: E501

    def translation_update_with_http_info(self, project_id, id, translation_update_parameters, **kwargs):  # noqa: E501
        """Update a translation  # noqa: E501

        Update an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_update_with_http_info(project_id, id, translation_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationUpdateParameters translation_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'translation_update_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_update`")  # noqa: E501
        # verify the required parameter 'translation_update_parameters' is set
        if self.api_client.client_side_validation and ('translation_update_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_update_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_update_parameters` when calling `translation_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_update_parameters' in local_var_params:
            body_params = local_var_params['translation_update_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translation_verify(self, project_id, id, translation_verify_parameters, **kwargs):  # noqa: E501
        """Verify a translation  # noqa: E501

        Verify an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_verify(project_id, id, translation_verify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationVerifyParameters translation_verify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TranslationDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translation_verify_with_http_info(project_id, id, translation_verify_parameters, **kwargs)  # noqa: E501

    def translation_verify_with_http_info(self, project_id, id, translation_verify_parameters, **kwargs):  # noqa: E501
        """Verify a translation  # noqa: E501

        Verify an existing translation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translation_verify_with_http_info(project_id, id, translation_verify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param TranslationVerifyParameters translation_verify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TranslationDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'translation_verify_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translation_verify" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translation_verify`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `translation_verify`")  # noqa: E501
        # verify the required parameter 'translation_verify_parameters' is set
        if self.api_client.client_side_validation and ('translation_verify_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translation_verify_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translation_verify_parameters` when calling `translation_verify`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translation_verify_parameters' in local_var_params:
            body_params = local_var_params['translation_verify_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/{id}/verify', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TranslationDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_by_key(self, project_id, key_id, **kwargs):  # noqa: E501
        """List translations by key  # noqa: E501

        List translations for a specific key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_by_key(project_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str key_id: Translation Key ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort criteria. Can be one of: key_name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Translation]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_by_key_with_http_info(project_id, key_id, **kwargs)  # noqa: E501

    def translations_by_key_with_http_info(self, project_id, key_id, **kwargs):  # noqa: E501
        """List translations by key  # noqa: E501

        List translations for a specific key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_by_key_with_http_info(project_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str key_id: Translation Key ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort criteria. Can be one of: key_name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Translation], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'key_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'branch',
            'sort',
            'order',
            'q'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_by_key" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_by_key`")  # noqa: E501
        # verify the required parameter 'key_id' is set
        if self.api_client.client_side_validation and ('key_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['key_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `key_id` when calling `translations_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'key_id' in local_var_params:
            path_params['key_id'] = local_var_params['key_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'order' in local_var_params and local_var_params['order'] is not None:  # noqa: E501
            query_params.append(('order', local_var_params['order']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/keys/{key_id}/translations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Translation]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_by_locale(self, project_id, locale_id, **kwargs):  # noqa: E501
        """List translations by locale  # noqa: E501

        List translations for a specific locale. If you want to download all translations for one locale we recommend to use the <code>locales#download</code> endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_by_locale(project_id, locale_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str locale_id: Locale ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort criteria. Can be one of: key_name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Translation]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_by_locale_with_http_info(project_id, locale_id, **kwargs)  # noqa: E501

    def translations_by_locale_with_http_info(self, project_id, locale_id, **kwargs):  # noqa: E501
        """List translations by locale  # noqa: E501

        List translations for a specific locale. If you want to download all translations for one locale we recommend to use the <code>locales#download</code> endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_by_locale_with_http_info(project_id, locale_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str locale_id: Locale ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort criteria. Can be one of: key_name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Translation], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'locale_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'branch',
            'sort',
            'order',
            'q'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_by_locale" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_by_locale`")  # noqa: E501
        # verify the required parameter 'locale_id' is set
        if self.api_client.client_side_validation and ('locale_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['locale_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `locale_id` when calling `translations_by_locale`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'locale_id' in local_var_params:
            path_params['locale_id'] = local_var_params['locale_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'order' in local_var_params and local_var_params['order'] is not None:  # noqa: E501
            query_params.append(('order', local_var_params['order']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/locales/{locale_id}/translations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Translation]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_exclude_collection(self, project_id, translations_exclude_parameters, **kwargs):  # noqa: E501
        """Set exclude from export flag on translations selected by query  # noqa: E501

        Exclude translations matching query from locale export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_exclude_collection(project_id, translations_exclude_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsExcludeParameters translations_exclude_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedCount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_exclude_collection_with_http_info(project_id, translations_exclude_parameters, **kwargs)  # noqa: E501

    def translations_exclude_collection_with_http_info(self, project_id, translations_exclude_parameters, **kwargs):  # noqa: E501
        """Set exclude from export flag on translations selected by query  # noqa: E501

        Exclude translations matching query from locale export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_exclude_collection_with_http_info(project_id, translations_exclude_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsExcludeParameters translations_exclude_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedCount, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translations_exclude_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_exclude_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_exclude_collection`")  # noqa: E501
        # verify the required parameter 'translations_exclude_parameters' is set
        if self.api_client.client_side_validation and ('translations_exclude_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translations_exclude_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translations_exclude_parameters` when calling `translations_exclude_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translations_exclude_parameters' in local_var_params:
            body_params = local_var_params['translations_exclude_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/exclude', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedCount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_include_collection(self, project_id, translations_include_parameters, **kwargs):  # noqa: E501
        """Remove exlude from import flag from translations selected by query  # noqa: E501

        Include translations matching query in locale export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_include_collection(project_id, translations_include_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsIncludeParameters translations_include_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedCount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_include_collection_with_http_info(project_id, translations_include_parameters, **kwargs)  # noqa: E501

    def translations_include_collection_with_http_info(self, project_id, translations_include_parameters, **kwargs):  # noqa: E501
        """Remove exlude from import flag from translations selected by query  # noqa: E501

        Include translations matching query in locale export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_include_collection_with_http_info(project_id, translations_include_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsIncludeParameters translations_include_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedCount, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translations_include_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_include_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_include_collection`")  # noqa: E501
        # verify the required parameter 'translations_include_parameters' is set
        if self.api_client.client_side_validation and ('translations_include_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translations_include_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translations_include_parameters` when calling `translations_include_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translations_include_parameters' in local_var_params:
            body_params = local_var_params['translations_include_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/include', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedCount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_list(self, project_id, **kwargs):  # noqa: E501
        """List all translations  # noqa: E501

        List translations for the given project. If you want to download all translations for one locale we recommend to use the <code>locales#download</code> endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_list(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort criteria. Can be one of: key_name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Translation]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_list_with_http_info(project_id, **kwargs)  # noqa: E501

    def translations_list_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List all translations  # noqa: E501

        List translations for the given project. If you want to download all translations for one locale we recommend to use the <code>locales#download</code> endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_list_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str sort: Sort criteria. Can be one of: key_name, created_at, updated_at.
        :param str order: Order direction. Can be one of: asc, desc.
        :param str q: Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Translation], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'branch',
            'sort',
            'order',
            'q'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'order' in local_var_params and local_var_params['order'] is not None:  # noqa: E501
            query_params.append(('order', local_var_params['order']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Translation]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_review_collection(self, project_id, translations_review_parameters, **kwargs):  # noqa: E501
        """Review translations selected by query  # noqa: E501

        Review translations matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_review_collection(project_id, translations_review_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsReviewParameters translations_review_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedCount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_review_collection_with_http_info(project_id, translations_review_parameters, **kwargs)  # noqa: E501

    def translations_review_collection_with_http_info(self, project_id, translations_review_parameters, **kwargs):  # noqa: E501
        """Review translations selected by query  # noqa: E501

        Review translations matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_review_collection_with_http_info(project_id, translations_review_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsReviewParameters translations_review_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedCount, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translations_review_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_review_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_review_collection`")  # noqa: E501
        # verify the required parameter 'translations_review_parameters' is set
        if self.api_client.client_side_validation and ('translations_review_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translations_review_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translations_review_parameters` when calling `translations_review_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translations_review_parameters' in local_var_params:
            body_params = local_var_params['translations_review_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/review', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedCount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_search(self, project_id, translations_search_parameters, **kwargs):  # noqa: E501
        """Search translations  # noqa: E501

        Search translations for the given project. Provides the same search interface as <code>translations#index</code> but allows POST requests to avoid limitations imposed by GET requests. If you want to download all translations for one locale we recommend to use the <code>locales#download</code> endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_search(project_id, translations_search_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsSearchParameters translations_search_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Translation]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_search_with_http_info(project_id, translations_search_parameters, **kwargs)  # noqa: E501

    def translations_search_with_http_info(self, project_id, translations_search_parameters, **kwargs):  # noqa: E501
        """Search translations  # noqa: E501

        Search translations for the given project. Provides the same search interface as <code>translations#index</code> but allows POST requests to avoid limitations imposed by GET requests. If you want to download all translations for one locale we recommend to use the <code>locales#download</code> endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_search_with_http_info(project_id, translations_search_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsSearchParameters translations_search_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Translation], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translations_search_parameters',
            'x_phrase_app_otp',
            'page',
            'per_page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_search`")  # noqa: E501
        # verify the required parameter 'translations_search_parameters' is set
        if self.api_client.client_side_validation and ('translations_search_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translations_search_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translations_search_parameters` when calling `translations_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translations_search_parameters' in local_var_params:
            body_params = local_var_params['translations_search_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Translation]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_unverify_collection(self, project_id, translations_unverify_parameters, **kwargs):  # noqa: E501
        """Mark translations selected by query as unverified  # noqa: E501

        Mark translations matching query as unverified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_unverify_collection(project_id, translations_unverify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsUnverifyParameters translations_unverify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedCount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_unverify_collection_with_http_info(project_id, translations_unverify_parameters, **kwargs)  # noqa: E501

    def translations_unverify_collection_with_http_info(self, project_id, translations_unverify_parameters, **kwargs):  # noqa: E501
        """Mark translations selected by query as unverified  # noqa: E501

        Mark translations matching query as unverified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_unverify_collection_with_http_info(project_id, translations_unverify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsUnverifyParameters translations_unverify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedCount, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translations_unverify_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_unverify_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_unverify_collection`")  # noqa: E501
        # verify the required parameter 'translations_unverify_parameters' is set
        if self.api_client.client_side_validation and ('translations_unverify_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translations_unverify_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translations_unverify_parameters` when calling `translations_unverify_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translations_unverify_parameters' in local_var_params:
            body_params = local_var_params['translations_unverify_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/unverify', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedCount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translations_verify_collection(self, project_id, translations_verify_parameters, **kwargs):  # noqa: E501
        """Verify translations selected by query  # noqa: E501

        Verify translations matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_verify_collection(project_id, translations_verify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsVerifyParameters translations_verify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AffectedCount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.translations_verify_collection_with_http_info(project_id, translations_verify_parameters, **kwargs)  # noqa: E501

    def translations_verify_collection_with_http_info(self, project_id, translations_verify_parameters, **kwargs):  # noqa: E501
        """Verify translations selected by query  # noqa: E501

        Verify translations matching query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translations_verify_collection_with_http_info(project_id, translations_verify_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param TranslationsVerifyParameters translations_verify_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AffectedCount, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'translations_verify_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translations_verify_collection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `translations_verify_collection`")  # noqa: E501
        # verify the required parameter 'translations_verify_parameters' is set
        if self.api_client.client_side_validation and ('translations_verify_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['translations_verify_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `translations_verify_parameters` when calling `translations_verify_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'translations_verify_parameters' in local_var_params:
            body_params = local_var_params['translations_verify_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/translations/verify', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AffectedCount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from phrase_api.api.accounts_api import AccountsApi
from phrase_api.api.authorizations_api import AuthorizationsApi
from phrase_api.api.bitbucket_sync_api import BitbucketSyncApi
from phrase_api.api.blacklisted_keys_api import BlacklistedKeysApi
from phrase_api.api.branches_api import BranchesApi
from phrase_api.api.comments_api import CommentsApi
from phrase_api.api.distributions_api import DistributionsApi
from phrase_api.api.documents_api import DocumentsApi
from phrase_api.api.formats_api import FormatsApi
from phrase_api.api.git_hub_sync_api import GitHubSyncApi
from phrase_api.api.git_lab_sync_api import GitLabSyncApi
from phrase_api.api.glossaries_api import GlossariesApi
from phrase_api.api.glossary_term_translations_api import GlossaryTermTranslationsApi
from phrase_api.api.glossary_terms_api import GlossaryTermsApi
from phrase_api.api.icu_api import ICUApi
from phrase_api.api.invitations_api import InvitationsApi
from phrase_api.api.job_comments_api import JobCommentsApi
from phrase_api.api.job_locales_api import JobLocalesApi
from phrase_api.api.job_template_locales_api import JobTemplateLocalesApi
from phrase_api.api.job_templates_api import JobTemplatesApi
from phrase_api.api.jobs_api import JobsApi
from phrase_api.api.keys_api import KeysApi
from phrase_api.api.locales_api import LocalesApi
from phrase_api.api.members_api import MembersApi
from phrase_api.api.notification_groups_api import NotificationGroupsApi
from phrase_api.api.notifications_api import NotificationsApi
from phrase_api.api.orders_api import OrdersApi
from phrase_api.api.projects_api import ProjectsApi
from phrase_api.api.releases_api import ReleasesApi
from phrase_api.api.screenshot_markers_api import ScreenshotMarkersApi
from phrase_api.api.screenshots_api import ScreenshotsApi
from phrase_api.api.search_api import SearchApi
from phrase_api.api.spaces_api import SpacesApi
from phrase_api.api.style_guides_api import StyleGuidesApi
from phrase_api.api.tags_api import TagsApi
from phrase_api.api.teams_api import TeamsApi
from phrase_api.api.translations_api import TranslationsApi
from phrase_api.api.uploads_api import UploadsApi
from phrase_api.api.users_api import UsersApi
from phrase_api.api.variables_api import VariablesApi
from phrase_api.api.versions___history_api import VersionsHistoryApi
from phrase_api.api.webhook_deliveries_api import WebhookDeliveriesApi
from phrase_api.api.webhooks_api import WebhooksApi



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.upload_create_parameters import UploadCreateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestUploadCreateParameters(unittest.TestCase):
    """UploadCreateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UploadCreateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.upload_create_parameters.UploadCreateParameters()  # noqa: E501
        if include_optional :
            return UploadCreateParameters(
                branch = 'my-feature-branch', 
                file = bytes(b'blah'), 
                file_format = 'json', 
                locale_id = 'abcd1234cdef1234abcd1234cdef1234', 
                tags = 'awesome-feature,needs-proofreading', 
                update_translations = True, 
                update_descriptions = True, 
                convert_emoji = True, 
                skip_upload_tags = True, 
                skip_unverification = True, 
                file_encoding = '0', 
                locale_mapping = {"en": "2"}, 
                format_options = {"foo": "bar"}, 
                autotranslate = True, 
                mark_reviewed = True
            )
        else :
            return UploadCreateParameters(
        )

    def testUploadCreateParameters(self):
        """Test UploadCreateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.5.3"

# import apis into sdk package
from phrase_api.api.accounts_api import AccountsApi
from phrase_api.api.authorizations_api import AuthorizationsApi
from phrase_api.api.bitbucket_sync_api import BitbucketSyncApi
from phrase_api.api.blacklisted_keys_api import BlacklistedKeysApi
from phrase_api.api.branches_api import BranchesApi
from phrase_api.api.comments_api import CommentsApi
from phrase_api.api.distributions_api import DistributionsApi
from phrase_api.api.documents_api import DocumentsApi
from phrase_api.api.formats_api import FormatsApi
from phrase_api.api.git_hub_sync_api import GitHubSyncApi
from phrase_api.api.git_lab_sync_api import GitLabSyncApi
from phrase_api.api.glossaries_api import GlossariesApi
from phrase_api.api.glossary_term_translations_api import GlossaryTermTranslationsApi
from phrase_api.api.glossary_terms_api import GlossaryTermsApi
from phrase_api.api.icu_api import ICUApi
from phrase_api.api.invitations_api import InvitationsApi
from phrase_api.api.job_comments_api import JobCommentsApi
from phrase_api.api.job_locales_api import JobLocalesApi
from phrase_api.api.job_template_locales_api import JobTemplateLocalesApi
from phrase_api.api.job_templates_api import JobTemplatesApi
from phrase_api.api.jobs_api import JobsApi
from phrase_api.api.keys_api import KeysApi
from phrase_api.api.locales_api import LocalesApi
from phrase_api.api.members_api import MembersApi
from phrase_api.api.notification_groups_api import NotificationGroupsApi
from phrase_api.api.notifications_api import NotificationsApi
from phrase_api.api.orders_api import OrdersApi
from phrase_api.api.projects_api import ProjectsApi
from phrase_api.api.releases_api import ReleasesApi
from phrase_api.api.screenshot_markers_api import ScreenshotMarkersApi
from phrase_api.api.screenshots_api import ScreenshotsApi
from phrase_api.api.search_api import SearchApi
from phrase_api.api.spaces_api import SpacesApi
from phrase_api.api.style_guides_api import StyleGuidesApi
from phrase_api.api.tags_api import TagsApi
from phrase_api.api.teams_api import TeamsApi
from phrase_api.api.translations_api import TranslationsApi
from phrase_api.api.uploads_api import UploadsApi
from phrase_api.api.users_api import UsersApi
from phrase_api.api.variables_api import VariablesApi
from phrase_api.api.versions___history_api import VersionsHistoryApi
from phrase_api.api.webhook_deliveries_api import WebhookDeliveriesApi
from phrase_api.api.webhooks_api import WebhooksApi

# import ApiClient
from phrase_api.api_client import ApiClient
from phrase_api.configuration import Configuration
from phrase_api.exceptions import OpenApiException
from phrase_api.exceptions import ApiTypeError
from phrase_api.exceptions import ApiValueError
from phrase_api.exceptions import ApiKeyError
from phrase_api.exceptions import ApiException
# import models into sdk package
from phrase_api.models.account import Account
from phrase_api.models.account_details import AccountDetails
from phrase_api.models.account_details1 import AccountDetails1
from phrase_api.models.account_search_result import AccountSearchResult
from phrase_api.models.affected_count import AffectedCount
from phrase_api.models.affected_resources import AffectedResources
from phrase_api.models.authorization import Authorization
from phrase_api.models.authorization_create_parameters import AuthorizationCreateParameters
from phrase_api.models.authorization_update_parameters import AuthorizationUpdateParameters
from phrase_api.models.authorization_with_token import AuthorizationWithToken
from phrase_api.models.authorization_with_token1 import AuthorizationWithToken1
from phrase_api.models.bitbucket_sync import BitbucketSync
from phrase_api.models.bitbucket_sync_export_parameters import BitbucketSyncExportParameters
from phrase_api.models.bitbucket_sync_export_response import BitbucketSyncExportResponse
from phrase_api.models.bitbucket_sync_import_parameters import BitbucketSyncImportParameters
from phrase_api.models.blacklisted_key import BlacklistedKey
from phrase_api.models.blacklisted_key_create_parameters import BlacklistedKeyCreateParameters
from phrase_api.models.blacklisted_key_update_parameters import BlacklistedKeyUpdateParameters
from phrase_api.models.branch import Branch
from phrase_api.models.branch_create_parameters import BranchCreateParameters
from phrase_api.models.branch_merge_parameters import BranchMergeParameters
from phrase_api.models.branch_name import BranchName
from phrase_api.models.branch_update_parameters import BranchUpdateParameters
from phrase_api.models.comment import Comment
from phrase_api.models.comment_create_parameters import CommentCreateParameters
from phrase_api.models.comment_mark_read_parameters import CommentMarkReadParameters
from phrase_api.models.comment_update_parameters import CommentUpdateParameters
from phrase_api.models.current_user import CurrentUser
from phrase_api.models.distribution import Distribution
from phrase_api.models.distribution_create_parameters import DistributionCreateParameters
from phrase_api.models.distribution_preview import DistributionPreview
from phrase_api.models.distribution_update_parameters import DistributionUpdateParameters
from phrase_api.models.document import Document
from phrase_api.models.format import Format
from phrase_api.models.github_sync_export_parameters import GithubSyncExportParameters
from phrase_api.models.github_sync_import_parameters import GithubSyncImportParameters
from phrase_api.models.gitlab_sync import GitlabSync
from phrase_api.models.gitlab_sync_export import GitlabSyncExport
from phrase_api.models.gitlab_sync_export_parameters import GitlabSyncExportParameters
from phrase_api.models.gitlab_sync_history import GitlabSyncHistory
from phrase_api.models.gitlab_sync_import_parameters import GitlabSyncImportParameters
from phrase_api.models.glossary import Glossary
from phrase_api.models.glossary_create_parameters import GlossaryCreateParameters
from phrase_api.models.glossary_term import GlossaryTerm
from phrase_api.models.glossary_term_create_parameters import GlossaryTermCreateParameters
from phrase_api.models.glossary_term_translation import GlossaryTermTranslation
from phrase_api.models.glossary_term_translation_create_parameters import GlossaryTermTranslationCreateParameters
from phrase_api.models.glossary_term_translation_update_parameters import GlossaryTermTranslationUpdateParameters
from phrase_api.models.glossary_term_update_parameters import GlossaryTermUpdateParameters
from phrase_api.models.glossary_update_parameters import GlossaryUpdateParameters
from phrase_api.models.icu import Icu
from phrase_api.models.icu_skeleton_parameters import IcuSkeletonParameters
from phrase_api.models.inline_response422 import InlineResponse422
from phrase_api.models.inline_response422_errors import InlineResponse422Errors
from phrase_api.models.invitation import Invitation
from phrase_api.models.invitation_create_parameters import InvitationCreateParameters
from phrase_api.models.invitation_update_parameters import InvitationUpdateParameters
from phrase_api.models.invitation_update_settings_parameters import InvitationUpdateSettingsParameters
from phrase_api.models.job import Job
from phrase_api.models.job_comment import JobComment
from phrase_api.models.job_comment_create_parameters import JobCommentCreateParameters
from phrase_api.models.job_comment_update_parameters import JobCommentUpdateParameters
from phrase_api.models.job_complete_parameters import JobCompleteParameters
from phrase_api.models.job_create_parameters import JobCreateParameters
from phrase_api.models.job_details import JobDetails
from phrase_api.models.job_details1 import JobDetails1
from phrase_api.models.job_keys_create_parameters import JobKeysCreateParameters
from phrase_api.models.job_locale import JobLocale
from phrase_api.models.job_locale_complete_parameters import JobLocaleCompleteParameters
from phrase_api.models.job_locale_complete_review_parameters import JobLocaleCompleteReviewParameters
from phrase_api.models.job_locale_reopen_parameters import JobLocaleReopenParameters
from phrase_api.models.job_locale_update_parameters import JobLocaleUpdateParameters
from phrase_api.models.job_locales_create_parameters import JobLocalesCreateParameters
from phrase_api.models.job_preview import JobPreview
from phrase_api.models.job_reopen_parameters import JobReopenParameters
from phrase_api.models.job_start_parameters import JobStartParameters
from phrase_api.models.job_template import JobTemplate
from phrase_api.models.job_template_create_parameters import JobTemplateCreateParameters
from phrase_api.models.job_template_locale import JobTemplateLocale
from phrase_api.models.job_template_locale_update_parameters import JobTemplateLocaleUpdateParameters
from phrase_api.models.job_template_locales_create_parameters import JobTemplateLocalesCreateParameters
from phrase_api.models.job_template_preview import JobTemplatePreview
from phrase_api.models.job_template_update_parameters import JobTemplateUpdateParameters
from phrase_api.models.job_template_user_preview import JobTemplateUserPreview
from phrase_api.models.job_update_parameters import JobUpdateParameters
from phrase_api.models.key_create_parameters import KeyCreateParameters
from phrase_api.models.key_preview import KeyPreview
from phrase_api.models.key_update_parameters import KeyUpdateParameters
from phrase_api.models.keys_exclude_parameters import KeysExcludeParameters
from phrase_api.models.keys_include_parameters import KeysIncludeParameters
from phrase_api.models.keys_search_parameters import KeysSearchParameters
from phrase_api.models.keys_tag_parameters import KeysTagParameters
from phrase_api.models.keys_untag_parameters import KeysUntagParameters
from phrase_api.models.locale import Locale
from phrase_api.models.locale_create_parameters import LocaleCreateParameters
from phrase_api.models.locale_details import LocaleDetails
from phrase_api.models.locale_details1 import LocaleDetails1
from phrase_api.models.locale_preview import LocalePreview
from phrase_api.models.locale_preview1 import LocalePreview1
from phrase_api.models.locale_statistics import LocaleStatistics
from phrase_api.models.locale_update_parameters import LocaleUpdateParameters
from phrase_api.models.member import Member
from phrase_api.models.member_project_detail import MemberProjectDetail
from phrase_api.models.member_project_detail_project_roles import MemberProjectDetailProjectRoles
from phrase_api.models.member_spaces import MemberSpaces
from phrase_api.models.member_update_parameters import MemberUpdateParameters
from phrase_api.models.member_update_settings_parameters import MemberUpdateSettingsParameters
from phrase_api.models.notification import Notification
from phrase_api.models.notification_group import NotificationGroup
from phrase_api.models.notification_group_detail import NotificationGroupDetail
from phrase_api.models.order_confirm_parameters import OrderConfirmParameters
from phrase_api.models.order_create_parameters import OrderCreateParameters
from phrase_api.models.project import Project
from phrase_api.models.project_create_parameters import ProjectCreateParameters
from phrase_api.models.project_details import ProjectDetails
from phrase_api.models.project_details1 import ProjectDetails1
from phrase_api.models.project_locales import ProjectLocales
from phrase_api.models.project_locales1 import ProjectLocales1
from phrase_api.models.project_member_specific import ProjectMemberSpecific
from phrase_api.models.project_short import ProjectShort
from phrase_api.models.project_update_parameters import ProjectUpdateParameters
from phrase_api.models.release import Release
from phrase_api.models.release_create_parameters import ReleaseCreateParameters
from phrase_api.models.release_preview import ReleasePreview
from phrase_api.models.release_update_parameters import ReleaseUpdateParameters
from phrase_api.models.screenshot import Screenshot
from phrase_api.models.screenshot_create_parameters import ScreenshotCreateParameters
from phrase_api.models.screenshot_marker import ScreenshotMarker
from phrase_api.models.screenshot_marker_create_parameters import ScreenshotMarkerCreateParameters
from phrase_api.models.screenshot_marker_update_parameters import ScreenshotMarkerUpdateParameters
from phrase_api.models.screenshot_update_parameters import ScreenshotUpdateParameters
from phrase_api.models.search_in_account_parameters import SearchInAccountParameters
from phrase_api.models.space import Space
from phrase_api.models.space1 import Space1
from phrase_api.models.space_create_parameters import SpaceCreateParameters
from phrase_api.models.space_update_parameters import SpaceUpdateParameters
from phrase_api.models.spaces_projects_create_parameters import SpacesProjectsCreateParameters
from phrase_api.models.styleguide import Styleguide
from phrase_api.models.styleguide_create_parameters import StyleguideCreateParameters
from phrase_api.models.styleguide_details import StyleguideDetails
from phrase_api.models.styleguide_details1 import StyleguideDetails1
from phrase_api.models.styleguide_preview import StyleguidePreview
from phrase_api.models.styleguide_update_parameters import StyleguideUpdateParameters
from phrase_api.models.subscription import Subscription
from phrase_api.models.tag import Tag
from phrase_api.models.tag_create_parameters import TagCreateParameters
from phrase_api.models.tag_with_stats import TagWithStats
from phrase_api.models.tag_with_stats1 import TagWithStats1
from phrase_api.models.tag_with_stats1_statistics import TagWithStats1Statistics
from phrase_api.models.tag_with_stats1_statistics1 import TagWithStats1Statistics1
from phrase_api.models.team import Team
from phrase_api.models.team_create_parameters import TeamCreateParameters
from phrase_api.models.team_detail import TeamDetail
from phrase_api.models.team_short import TeamShort
from phrase_api.models.team_update_parameters import TeamUpdateParameters
from phrase_api.models.teams_projects_create_parameters import TeamsProjectsCreateParameters
from phrase_api.models.teams_spaces_create_parameters import TeamsSpacesCreateParameters
from phrase_api.models.teams_users_create_parameters import TeamsUsersCreateParameters
from phrase_api.models.translation import Translation
from phrase_api.models.translation_create_parameters import TranslationCreateParameters
from phrase_api.models.translation_details import TranslationDetails
from phrase_api.models.translation_details1 import TranslationDetails1
from phrase_api.models.translation_exclude_parameters import TranslationExcludeParameters
from phrase_api.models.translation_include_parameters import TranslationIncludeParameters
from phrase_api.models.translation_key import TranslationKey
from phrase_api.models.translation_key_details import TranslationKeyDetails
from phrase_api.models.translation_key_details1 import TranslationKeyDetails1
from phrase_api.models.translation_order import TranslationOrder
from phrase_api.models.translation_review_parameters import TranslationReviewParameters
from phrase_api.models.translation_unverify_parameters import TranslationUnverifyParameters
from phrase_api.models.translation_update_parameters import TranslationUpdateParameters
from phrase_api.models.translation_verify_parameters import TranslationVerifyParameters
from phrase_api.models.translation_version import TranslationVersion
from phrase_api.models.translation_version_with_user import TranslationVersionWithUser
from phrase_api.models.translation_version_with_user1 import TranslationVersionWithUser1
from phrase_api.models.translations_exclude_parameters import TranslationsExcludeParameters
from phrase_api.models.translations_include_parameters import TranslationsIncludeParameters
from phrase_api.models.translations_review_parameters import TranslationsReviewParameters
from phrase_api.models.translations_search_parameters import TranslationsSearchParameters
from phrase_api.models.translations_unverify_parameters import TranslationsUnverifyParameters
from phrase_api.models.translations_verify_parameters import TranslationsVerifyParameters
from phrase_api.models.upload import Upload
from phrase_api.models.upload_create_parameters import UploadCreateParameters
from phrase_api.models.upload_summary import UploadSummary
from phrase_api.models.user import User
from phrase_api.models.user_preview import UserPreview
from phrase_api.models.variable import Variable
from phrase_api.models.variable_create_parameters import VariableCreateParameters
from phrase_api.models.variable_update_parameters import VariableUpdateParameters
from phrase_api.models.webhook import Webhook
from phrase_api.models.webhook_create_parameters import WebhookCreateParameters
from phrase_api.models.webhook_delivery import WebhookDelivery
from phrase_api.models.webhook_update_parameters import WebhookUpdateParameters




# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.comments_api import CommentsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestCommentsApi(unittest.TestCase):
    """CommentsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.comments_api.CommentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_comment_create(self):
        """Test case for comment_create

        Create a comment  # noqa: E501
        """
        pass

    def test_comment_delete(self):
        """Test case for comment_delete

        Delete a comment  # noqa: E501
        """
        pass

    def test_comment_mark_check(self):
        """Test case for comment_mark_check

        Check if comment is read  # noqa: E501
        """
        pass

    def test_comment_mark_read(self):
        """Test case for comment_mark_read

        Mark a comment as read  # noqa: E501
        """
        pass

    def test_comment_mark_unread(self):
        """Test case for comment_mark_unread

        Mark a comment as unread  # noqa: E501
        """
        pass

    def test_comment_show(self):
        """Test case for comment_show

        Get a single comment  # noqa: E501
        """
        pass

    def test_comment_update(self):
        """Test case for comment_update

        Update a comment  # noqa: E501
        """
        pass

    def test_comments_list(self):
        """Test case for comments_list

        List comments  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "phrase-api"
VERSION = "1.5.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Phrase Strings API Reference",
    author="Phrase Support",
    author_email="support@phrase.com",
    url="https://github.com/phrase/phrase-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "Phrase Strings API Reference"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description="""\
    Phrase Strings is a translation management platform for software projects. You can collaborate on language file translation with your team or order translations through our platform. The API allows you to import locale files, download locale files, tag keys or interact in other ways with the localization data stored in Phrase Strings for your account.
    """
)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.keys_api import KeysApi  # noqa: E501
from phrase_api.rest import ApiException


class TestKeysApi(unittest.TestCase):
    """KeysApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.keys_api.KeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_key_create(self):
        """Test case for key_create

        Create a key  # noqa: E501
        """
        pass

    def test_key_delete(self):
        """Test case for key_delete

        Delete a key  # noqa: E501
        """
        pass

    def test_key_show(self):
        """Test case for key_show

        Get a single key  # noqa: E501
        """
        pass

    def test_key_update(self):
        """Test case for key_update

        Update a key  # noqa: E501
        """
        pass

    def test_keys_delete_collection(self):
        """Test case for keys_delete_collection

        Delete collection of keys  # noqa: E501
        """
        pass

    def test_keys_exclude(self):
        """Test case for keys_exclude

        Exclude a locale on a collection of keys  # noqa: E501
        """
        pass

    def test_keys_include(self):
        """Test case for keys_include

        Include a locale on a collection of keys  # noqa: E501
        """
        pass

    def test_keys_list(self):
        """Test case for keys_list

        List keys  # noqa: E501
        """
        pass

    def test_keys_search(self):
        """Test case for keys_search

        Search keys  # noqa: E501
        """
        pass

    def test_keys_tag(self):
        """Test case for keys_tag

        Add tags to collection of keys  # noqa: E501
        """
        pass

    def test_keys_untag(self):
        """Test case for keys_untag

        Remove tags from collection of keys  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.invitations_api import InvitationsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestInvitationsApi(unittest.TestCase):
    """InvitationsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.invitations_api.InvitationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_invitation_create(self):
        """Test case for invitation_create

        Create a new invitation  # noqa: E501
        """
        pass

    def test_invitation_delete(self):
        """Test case for invitation_delete

        Delete an invitation  # noqa: E501
        """
        pass

    def test_invitation_resend(self):
        """Test case for invitation_resend

        Resend an invitation  # noqa: E501
        """
        pass

    def test_invitation_show(self):
        """Test case for invitation_show

        Get a single invitation  # noqa: E501
        """
        pass

    def test_invitation_update(self):
        """Test case for invitation_update

        Update an invitation  # noqa: E501
        """
        pass

    def test_invitation_update_settings(self):
        """Test case for invitation_update_settings

        Update a member's invitation access  # noqa: E501
        """
        pass

    def test_invitations_list(self):
        """Test case for invitations_list

        List invitations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
